/*
 *	WGAppDelegate.m
 *		・AppDelegate
 *		・アプリの振る舞いを決定します。  
 *
 *  Copyright (c) 2001 Tomonori Tomatsu. All rights reserved.
 */
#import "WGAppDelegate.h"

@implementation WGAppDelegate
///////////////////////////////////////////////////
// 		 初期化と解放			 //
///////////////////////////////////////////////////
/*===================================
    init 
=====================================*/
- (id)init
{
    [ super init ];

    mDownloadingNum = 0;
    mOpenDropItem = NO;
    mAppLaunched = NO;
    mLocationPath = [ [ NSMutableString alloc ] init ];
    mLocationPathDictionary = [ [ NSDictionary alloc ] initWithObjectsAndKeys : mLocationPath, kWGOpenLocationKey, nil ];
    
    [ [ NSNotificationCenter defaultCenter ] addObserver : self 
						selector : @selector( nowStartDownload : ) 
						    name : kWGNowStartDownloadNotification 
						  object : nil ];
    [ [ NSNotificationCenter defaultCenter ] addObserver : self 
						selector : @selector( nowTerminateDownload: ) 
						    name : kWGNowTerminateDownloadNotification 
						  object : nil ];
    [ [ NSNotificationCenter defaultCenter ] addObserver : self 
						selector : @selector( giveMeOpenLocation: ) 
						    name : kWGGiveMeOpenLocationNotification 
						  object : nil ];

    return self;
}

/*===================================
    dealloc 
=====================================*/
- (void)dealloc
{    
    [ [ NSNotificationCenter defaultCenter ] removeObserver : self ];
    [ mLocationPath release ];

    [ super dealloc ];
}

//////////////////////////////////////////////////
// 	NSApplication's delegate		//
//////////////////////////////////////////////////
/*===================================
    applicationShouldTerminate
	アプリを終了してもよいですか？って時に呼ばれる。 
=====================================*/
- (NSApplicationTerminateReply)applicationShouldTerminate : (NSApplication *)sender
{
    int		theAlertPanel;
    NSBundle*	theBundle = [ NSBundle mainBundle ];
    NSString*	theOKStr = [ theBundle localizedStringForKey : @"OK" value : @"OK" table : nil ];
    NSString*	theCancelStr = [ theBundle localizedStringForKey : @"Cancel" value : @"Cancel" table : nil ];
    NSString*	theNowDownloadingsWouldYouStopThemStr = [ theBundle localizedStringForKey : @"Now Downloading(s)...\nWould you stop it(them)?" value : @"Now Downloading(s)...\nWould you stop it(them)?" table : nil ];

    if ( mDownloadingNum ) {
	theAlertPanel = NSRunAlertPanel( @"wget+", theNowDownloadingsWouldYouStopThemStr, theOKStr, theCancelStr, nil );
	
	if ( NSAlertAlternateReturn == theAlertPanel ) {
	    return NSTerminateCancel;
	}
    }
    
    return NSTerminateNow;
}

/*===================================
    applicationopenFile
	アプリアイコンへドロップ受け付け 
=====================================*/
- (BOOL)application : (NSApplication *)sender openFile : (NSString *)filename
{
NSPasteboard*	thePb = nil;
    mOpenDropItem = YES;
    [ mLocationPath setString : filename ];
    
////// test tomatsu
thePb = [ NSPasteboard pasteboardByFilteringFile : filename ];
    if ( mAppLaunched ) {
	[ [ NSDocumentController sharedDocumentController ] newDocument : self ];
	//[ [ [ NSDocumentController sharedDocumentController ] currentDocument ] openLocation : mLocationPath ];
    }

    return YES;
}

/*===================================
    applicationopenTempFile
	sampleでも?とか書いてあったのだが、何に使うんだろう？  
=====================================*/
- (BOOL)application : (NSApplication *)sender openTempFile : (NSString *)filename
{
    [ self application : sender openFile : filename ];
    
    return YES;
}

/*===================================
    applicationDidFinishLaunching
	起動過程終了時に呼ばれる  
=====================================*/
- (void)applicationDidFinishLaunching : (NSNotification *)notification
{
    mAppLaunched = YES;

    if ( mOpenDropItem ) {
	[ [ NSDocumentController sharedDocumentController ] newDocument : self ];
	//[ [ [ NSDocumentController sharedDocumentController ] currentDocument ] openLocation : mLocationPath ];

	mOpenDropItem = NO;
    }
}

//////////////////////////////////////////////////
// 		Notification			//
//////////////////////////////////////////////////
/*===================================
    nowStartDownload
	ダウンロード開始の通知受け付け  
=====================================*/
- (void)nowStartDownload : (NSNotification *)inNotification
{
    mDownloadingNum++;
}

/*===================================
    nowTerminateDownload
	ダウンロード終了の通知受け付け  
=====================================*/
- (void)nowTerminateDownload : (NSNotification *)inNotification
{
    mDownloadingNum--;
}

/*===================================
    giveMeOpenLocation
	kWGGiveMeOpenLocationNotificationの通知受け付け  
=====================================*/
- (void)giveMeOpenLocation : (NSNotification *)inNotification
{
    [ [ NSNotificationCenter defaultCenter ] postNotificationName : kWGOpenLocationDropedNotification
							   object : [ inNotification object ] 
							 userInfo : mLocationPathDictionary ];
    [ mLocationPath setString : @"" ];
}

@end
